import org.slf4j.Logger
import org.slf4j.LoggerFactory

import java.nio.file.Files

VERSION = "5.5.0"

Logger logger = LoggerFactory.getLogger(getClass().getName())

logger.info("BEGIN Validation")

String home = System.getProperty("service.home")

if (!home) {
    throw new IllegalArgumentException("No service.home provided")
}

File rootDir = new File(home).getCanonicalFile().getParentFile()
if (!rootDir.getName().endsWith("PulseNET")) {
    throw new IllegalArgumentException("Incorrect installer, please use addon-install bundled with PulseNET");
}
File manifest = new File(rootDir, "apache-tomcat/webapps/ROOT/META-INF/MANIFEST.MF")

String buildNumber = manifest.isFile() ? Files.readAllLines(manifest.toPath()).find{l -> l.startsWith("Build-Number:")} : "no manifest file"
String applyVersion = VERSION.replace("-SNAPSHOT", "")
logger.info("Server is '" + buildNumber + "', applying '" + applyVersion + "'")
if (!buildNumber || !buildNumber.contains(" " + applyVersion)) {
    throw new IllegalArgumentException("Expected '" + applyVersion + "' but found '" + buildNumber + "'")
}

logger.info("END Validation")
